[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --fast-version-control
![](https://git-scm.com/images/dark-mode.svg)
Git is a [free and open source](https://git-scm.com/about/#free-and-open-source) distributed version control system designed to handle everything from small to very large projects with speed and efficiency.
Git is [lightning fast](https://git-scm.com/about) and has a huge ecosystem of [GUIs](https://git-scm.com/tools/guis), [hosting services](https://git-scm.com/tools/hosting), and [command-line tools](https://git-scm.com/tools/command-line).
![](https://git-scm.com/images/branching-illustration@2x.png)
  * [ ![](https://git-scm.com/images/icons/fa-gears.svg) About Git's performance and ecosystem ](https://git-scm.com/about)
  * [ ![](https://git-scm.com/images/icons/fa-lightbulb.svg) Learn Pro Git book, videos, tutorials, and cheat sheet ](https://git-scm.com/learn)
  * [ ![](https://git-scm.com/images/icons/fa-screwdriver-wrench.svg) Tools Command line tools, GUIs, and hosting services ](https://git-scm.com/tools)
  * [ ![](https://git-scm.com/images/icons/fa-book-open.svg) Reference Git's reference documentation ](https://git-scm.com/docs)
  * [ ![](https://git-scm.com/images/icons/fa-down-long.svg) Install Binary releases for all major platforms. ](https://git-scm.com/install/linux)
  * [ ![](https://git-scm.com/images/icons/fa-comments.svg) Community Get involved! Bug reporting, mailing list, chat, development and more. ](https://git-scm.com/community)


![](https://git-scm.com/images/progit2.png)
**[Pro Git](https://git-scm.com/book)** by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
#### Latest source release
2.53.0 [Release Notes](https://gitlab.com/git-scm/git/-/blob/HEAD/Documentation/RelNotes/2.53.0.adoc) (2026-02-02)
[Install for Linux](https://git-scm.com/install/linux) [ GitHub Repository ](https://github.com/git/git)
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
